import { defineComponent, ref, provide, computed, withDirectives, openBlock, createBlock, unref, withCtx, createElementVNode, normalizeClass, normalizeStyle, createSlots, renderSlot, createCommentVNode, vShow } from 'vue';
import { PsOverlay } from '../../overlay/index.mjs';
import '../../../hooks/index.mjs';
import '../../../tokens/index.mjs';
import PsDialogContent from './dialog-content.mjs';
import { dialogProps } from './dialog.mjs';
import { useDialog } from './use-dialog.mjs';
import _export_sfc from '../../../_virtual/plugin-vue_export-helper.mjs';
import { useNamespace } from '../../../hooks/use-namespace/index.mjs';
import { dialogInjectionKey } from '../../../tokens/dialog.mjs';
import { useDraggable } from '../../../hooks/use-draggable/index.mjs';

const __default__ = {
  name: "PsDialog"
};
const _sfc_main = /* @__PURE__ */ defineComponent({
  ...__default__,
  props: dialogProps,
  setup(__props, { expose }) {
    const props = __props;
    const ns = useNamespace("dialog");
    const dialogRef = ref();
    const headerRef = ref();
    const {
      visible,
      style,
      rendered,
      zIndex
    } = useDialog(props, dialogRef);
    provide(dialogInjectionKey, {
      dialogRef,
      headerRef,
      ns,
      rendered,
      style
    });
    const draggable = computed(() => props.draggable && !props.fullscreen);
    useDraggable(dialogRef, headerRef, draggable);
    expose({
      visible
    });
    return (_ctx, _cache) => {
      return withDirectives((openBlock(), createBlock(unref(PsOverlay), {
        "custom-mask-event": "",
        mask: _ctx.modal,
        "overlay-class": (_ctx.modalClass || "") + (_ctx.widget ? ` ps--dialog-widget-class` : ""),
        "z-index": unref(zIndex)
      }, {
        default: withCtx(() => [
          createElementVNode("div", {
            class: normalizeClass(`${unref(ns).namespace.value}-overlay-dialog`)
          }, [
            unref(rendered) ? (openBlock(), createBlock(PsDialogContent, {
              key: 0,
              "custom-class": _ctx.customClass,
              center: _ctx.center,
              "close-icon": _ctx.closeIcon,
              draggable: unref(draggable),
              fullscreen: _ctx.fullscreen,
              "show-close": _ctx.showClose,
              style: normalizeStyle(unref(style)),
              title: _ctx.title,
              widget: _ctx.widget
            }, createSlots({
              title: withCtx(() => [
                renderSlot(_ctx.$slots, "title")
              ]),
              default: withCtx(() => [
                renderSlot(_ctx.$slots, "default")
              ]),
              _: 2
            }, [
              _ctx.$slots.footer ? {
                name: "footer",
                fn: withCtx(() => [
                  renderSlot(_ctx.$slots, "footer")
                ])
              } : void 0
            ]), 1032, ["custom-class", "center", "close-icon", "draggable", "fullscreen", "show-close", "style", "title", "widget"])) : createCommentVNode("v-if", true)
          ], 2)
        ]),
        _: 3
      }, 8, ["mask", "overlay-class", "z-index"])), [
        [vShow, unref(visible)]
      ]);
    };
  }
});
var Dialog = /* @__PURE__ */ _export_sfc(_sfc_main, [["__file", "/Users/meng/workspace/element-ps/packages/components/dialog/src/dialog.vue"]]);

export { Dialog as default };
//# sourceMappingURL=dialog2.mjs.map
